@@ -6,6 +6,10 @@ from subdomain_takeover_tools.helper.main import bootstrap
 
 
 def is_valid(name, _):
+    confirm_s3(name)
+
+
+def confirm_s3(name):
     try:
         s3 = boto3.resource('s3')
         s3.meta.client.head_bucket(Bucket=name)
@@ -13,12 +17,12 @@ def is_valid(name, _):
     except ClientError as e:
         response_code = e.response['Error']['Code']
         if '404' == response_code:
-            return confirm_s3(name)
+            return _confirm_http_response(name)
         elif '403' == response_code:
             return False
 
 
-def confirm_s3(name):
+def _confirm_http_response(name):
     try:
         r = requests.head("http://" + name)
         if 'x-amz-error-detail-BucketName' in r.headers:
